# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

import os
from typing import Any, cast

import pytest

from telnyx import Telnyx, AsyncTelnyx
from tests.utils import assert_matches_type
from telnyx.types import (
    AlphanumericSenderID,
    AlphanumericSenderIDCreateResponse,
    AlphanumericSenderIDDeleteResponse,
    AlphanumericSenderIDRetrieveResponse,
)
from telnyx.pagination import SyncDefaultFlatPagination, AsyncDefaultFlatPagination

base_url = os.environ.get("TEST_API_BASE_URL", "http://127.0.0.1:4010")


class TestAlphanumericSenderIDs:
    parametrize = pytest.mark.parametrize("client", [False, True], indirect=True, ids=["loose", "strict"])

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    def test_method_create(self, client: Telnyx) -> None:
        alphanumeric_sender_id = client.alphanumeric_sender_ids.create(
            alphanumeric_sender_id="MyCompany",
            messaging_profile_id="182bd5e5-6e1a-4fe4-a799-aa6d9a6ab26e",
        )
        assert_matches_type(AlphanumericSenderIDCreateResponse, alphanumeric_sender_id, path=["response"])

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    def test_method_create_with_all_params(self, client: Telnyx) -> None:
        alphanumeric_sender_id = client.alphanumeric_sender_ids.create(
            alphanumeric_sender_id="MyCompany",
            messaging_profile_id="182bd5e5-6e1a-4fe4-a799-aa6d9a6ab26e",
            us_long_code_fallback="+15551234567",
        )
        assert_matches_type(AlphanumericSenderIDCreateResponse, alphanumeric_sender_id, path=["response"])

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    def test_raw_response_create(self, client: Telnyx) -> None:
        response = client.alphanumeric_sender_ids.with_raw_response.create(
            alphanumeric_sender_id="MyCompany",
            messaging_profile_id="182bd5e5-6e1a-4fe4-a799-aa6d9a6ab26e",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        alphanumeric_sender_id = response.parse()
        assert_matches_type(AlphanumericSenderIDCreateResponse, alphanumeric_sender_id, path=["response"])

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    def test_streaming_response_create(self, client: Telnyx) -> None:
        with client.alphanumeric_sender_ids.with_streaming_response.create(
            alphanumeric_sender_id="MyCompany",
            messaging_profile_id="182bd5e5-6e1a-4fe4-a799-aa6d9a6ab26e",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            alphanumeric_sender_id = response.parse()
            assert_matches_type(AlphanumericSenderIDCreateResponse, alphanumeric_sender_id, path=["response"])

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    def test_method_retrieve(self, client: Telnyx) -> None:
        alphanumeric_sender_id = client.alphanumeric_sender_ids.retrieve(
            "id",
        )
        assert_matches_type(AlphanumericSenderIDRetrieveResponse, alphanumeric_sender_id, path=["response"])

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    def test_raw_response_retrieve(self, client: Telnyx) -> None:
        response = client.alphanumeric_sender_ids.with_raw_response.retrieve(
            "id",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        alphanumeric_sender_id = response.parse()
        assert_matches_type(AlphanumericSenderIDRetrieveResponse, alphanumeric_sender_id, path=["response"])

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    def test_streaming_response_retrieve(self, client: Telnyx) -> None:
        with client.alphanumeric_sender_ids.with_streaming_response.retrieve(
            "id",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            alphanumeric_sender_id = response.parse()
            assert_matches_type(AlphanumericSenderIDRetrieveResponse, alphanumeric_sender_id, path=["response"])

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    def test_path_params_retrieve(self, client: Telnyx) -> None:
        with pytest.raises(ValueError, match=r"Expected a non-empty value for `id` but received ''"):
            client.alphanumeric_sender_ids.with_raw_response.retrieve(
                "",
            )

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    def test_method_list(self, client: Telnyx) -> None:
        alphanumeric_sender_id = client.alphanumeric_sender_ids.list()
        assert_matches_type(SyncDefaultFlatPagination[AlphanumericSenderID], alphanumeric_sender_id, path=["response"])

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    def test_method_list_with_all_params(self, client: Telnyx) -> None:
        alphanumeric_sender_id = client.alphanumeric_sender_ids.list(
            filter_messaging_profile_id="182bd5e5-6e1a-4fe4-a799-aa6d9a6ab26e",
            page_number=0,
            page_size=0,
        )
        assert_matches_type(SyncDefaultFlatPagination[AlphanumericSenderID], alphanumeric_sender_id, path=["response"])

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    def test_raw_response_list(self, client: Telnyx) -> None:
        response = client.alphanumeric_sender_ids.with_raw_response.list()

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        alphanumeric_sender_id = response.parse()
        assert_matches_type(SyncDefaultFlatPagination[AlphanumericSenderID], alphanumeric_sender_id, path=["response"])

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    def test_streaming_response_list(self, client: Telnyx) -> None:
        with client.alphanumeric_sender_ids.with_streaming_response.list() as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            alphanumeric_sender_id = response.parse()
            assert_matches_type(
                SyncDefaultFlatPagination[AlphanumericSenderID], alphanumeric_sender_id, path=["response"]
            )

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    def test_method_delete(self, client: Telnyx) -> None:
        alphanumeric_sender_id = client.alphanumeric_sender_ids.delete(
            "id",
        )
        assert_matches_type(AlphanumericSenderIDDeleteResponse, alphanumeric_sender_id, path=["response"])

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    def test_raw_response_delete(self, client: Telnyx) -> None:
        response = client.alphanumeric_sender_ids.with_raw_response.delete(
            "id",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        alphanumeric_sender_id = response.parse()
        assert_matches_type(AlphanumericSenderIDDeleteResponse, alphanumeric_sender_id, path=["response"])

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    def test_streaming_response_delete(self, client: Telnyx) -> None:
        with client.alphanumeric_sender_ids.with_streaming_response.delete(
            "id",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            alphanumeric_sender_id = response.parse()
            assert_matches_type(AlphanumericSenderIDDeleteResponse, alphanumeric_sender_id, path=["response"])

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    def test_path_params_delete(self, client: Telnyx) -> None:
        with pytest.raises(ValueError, match=r"Expected a non-empty value for `id` but received ''"):
            client.alphanumeric_sender_ids.with_raw_response.delete(
                "",
            )


class TestAsyncAlphanumericSenderIDs:
    parametrize = pytest.mark.parametrize(
        "async_client", [False, True, {"http_client": "aiohttp"}], indirect=True, ids=["loose", "strict", "aiohttp"]
    )

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    async def test_method_create(self, async_client: AsyncTelnyx) -> None:
        alphanumeric_sender_id = await async_client.alphanumeric_sender_ids.create(
            alphanumeric_sender_id="MyCompany",
            messaging_profile_id="182bd5e5-6e1a-4fe4-a799-aa6d9a6ab26e",
        )
        assert_matches_type(AlphanumericSenderIDCreateResponse, alphanumeric_sender_id, path=["response"])

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    async def test_method_create_with_all_params(self, async_client: AsyncTelnyx) -> None:
        alphanumeric_sender_id = await async_client.alphanumeric_sender_ids.create(
            alphanumeric_sender_id="MyCompany",
            messaging_profile_id="182bd5e5-6e1a-4fe4-a799-aa6d9a6ab26e",
            us_long_code_fallback="+15551234567",
        )
        assert_matches_type(AlphanumericSenderIDCreateResponse, alphanumeric_sender_id, path=["response"])

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    async def test_raw_response_create(self, async_client: AsyncTelnyx) -> None:
        response = await async_client.alphanumeric_sender_ids.with_raw_response.create(
            alphanumeric_sender_id="MyCompany",
            messaging_profile_id="182bd5e5-6e1a-4fe4-a799-aa6d9a6ab26e",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        alphanumeric_sender_id = await response.parse()
        assert_matches_type(AlphanumericSenderIDCreateResponse, alphanumeric_sender_id, path=["response"])

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    async def test_streaming_response_create(self, async_client: AsyncTelnyx) -> None:
        async with async_client.alphanumeric_sender_ids.with_streaming_response.create(
            alphanumeric_sender_id="MyCompany",
            messaging_profile_id="182bd5e5-6e1a-4fe4-a799-aa6d9a6ab26e",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            alphanumeric_sender_id = await response.parse()
            assert_matches_type(AlphanumericSenderIDCreateResponse, alphanumeric_sender_id, path=["response"])

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    async def test_method_retrieve(self, async_client: AsyncTelnyx) -> None:
        alphanumeric_sender_id = await async_client.alphanumeric_sender_ids.retrieve(
            "id",
        )
        assert_matches_type(AlphanumericSenderIDRetrieveResponse, alphanumeric_sender_id, path=["response"])

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    async def test_raw_response_retrieve(self, async_client: AsyncTelnyx) -> None:
        response = await async_client.alphanumeric_sender_ids.with_raw_response.retrieve(
            "id",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        alphanumeric_sender_id = await response.parse()
        assert_matches_type(AlphanumericSenderIDRetrieveResponse, alphanumeric_sender_id, path=["response"])

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    async def test_streaming_response_retrieve(self, async_client: AsyncTelnyx) -> None:
        async with async_client.alphanumeric_sender_ids.with_streaming_response.retrieve(
            "id",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            alphanumeric_sender_id = await response.parse()
            assert_matches_type(AlphanumericSenderIDRetrieveResponse, alphanumeric_sender_id, path=["response"])

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    async def test_path_params_retrieve(self, async_client: AsyncTelnyx) -> None:
        with pytest.raises(ValueError, match=r"Expected a non-empty value for `id` but received ''"):
            await async_client.alphanumeric_sender_ids.with_raw_response.retrieve(
                "",
            )

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    async def test_method_list(self, async_client: AsyncTelnyx) -> None:
        alphanumeric_sender_id = await async_client.alphanumeric_sender_ids.list()
        assert_matches_type(AsyncDefaultFlatPagination[AlphanumericSenderID], alphanumeric_sender_id, path=["response"])

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    async def test_method_list_with_all_params(self, async_client: AsyncTelnyx) -> None:
        alphanumeric_sender_id = await async_client.alphanumeric_sender_ids.list(
            filter_messaging_profile_id="182bd5e5-6e1a-4fe4-a799-aa6d9a6ab26e",
            page_number=0,
            page_size=0,
        )
        assert_matches_type(AsyncDefaultFlatPagination[AlphanumericSenderID], alphanumeric_sender_id, path=["response"])

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    async def test_raw_response_list(self, async_client: AsyncTelnyx) -> None:
        response = await async_client.alphanumeric_sender_ids.with_raw_response.list()

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        alphanumeric_sender_id = await response.parse()
        assert_matches_type(AsyncDefaultFlatPagination[AlphanumericSenderID], alphanumeric_sender_id, path=["response"])

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    async def test_streaming_response_list(self, async_client: AsyncTelnyx) -> None:
        async with async_client.alphanumeric_sender_ids.with_streaming_response.list() as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            alphanumeric_sender_id = await response.parse()
            assert_matches_type(
                AsyncDefaultFlatPagination[AlphanumericSenderID], alphanumeric_sender_id, path=["response"]
            )

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    async def test_method_delete(self, async_client: AsyncTelnyx) -> None:
        alphanumeric_sender_id = await async_client.alphanumeric_sender_ids.delete(
            "id",
        )
        assert_matches_type(AlphanumericSenderIDDeleteResponse, alphanumeric_sender_id, path=["response"])

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    async def test_raw_response_delete(self, async_client: AsyncTelnyx) -> None:
        response = await async_client.alphanumeric_sender_ids.with_raw_response.delete(
            "id",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        alphanumeric_sender_id = await response.parse()
        assert_matches_type(AlphanumericSenderIDDeleteResponse, alphanumeric_sender_id, path=["response"])

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    async def test_streaming_response_delete(self, async_client: AsyncTelnyx) -> None:
        async with async_client.alphanumeric_sender_ids.with_streaming_response.delete(
            "id",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            alphanumeric_sender_id = await response.parse()
            assert_matches_type(AlphanumericSenderIDDeleteResponse, alphanumeric_sender_id, path=["response"])

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    async def test_path_params_delete(self, async_client: AsyncTelnyx) -> None:
        with pytest.raises(ValueError, match=r"Expected a non-empty value for `id` but received ''"):
            await async_client.alphanumeric_sender_ids.with_raw_response.delete(
                "",
            )
